package org.communiquons.dccaggregator.helper

import android.content.Context
import androidx.preference.PreferenceManager
import org.communiquons.dccaggregator.PREF_CERTS_LIST
import org.communiquons.dccaggregator.models.Certificate

class CertificatesList(context: Context) {
    private val prefsManager = PreferenceManager.getDefaultSharedPreferences(context)

    val hasGeneratedCertificate get() = false

    /**
     * The list of certificates, as a strings list
     */
    private var listString
        get() = prefsManager.getStringSet(PREF_CERTS_LIST, HashSet())!!
        set(v) = prefsManager.edit().putStringSet(PREF_CERTS_LIST, v).apply()

    /**
     * The list of decoded certificates
     */
    val certsList get() = listString.map { t -> Certificate(t) }

    /**
     * Check if a certificate is already present in the list or not
     */
    fun hasCertificate(cert: Certificate): Boolean {
        return certsList.any { it.id == cert.id }
    }

    /**
     * Add a certificate to the list
     */
    fun addCertificate(cert: Certificate) {
        listString = listString.apply { add(cert.encoded) }
    }
}
