package org.communiquons.dccaggregator.models

import android.content.Context
import dgca.verifier.app.decoder.CertificateDecodingResult
import dgca.verifier.app.decoder.DefaultCertificateDecoder
import dgca.verifier.app.decoder.base45.Base45Decoder
import dgca.verifier.app.decoder.model.GreenCertificate
import dgca.verifier.app.decoder.model.RecoveryStatement
import org.communiquons.dccaggregator.R

@OptIn(ExperimentalUnsignedTypes::class)
class Certificate(val encoded: String) {

    // Decoded green certificate
    val decoded: GreenCertificate

    init {
        val res = DefaultCertificateDecoder(Base45Decoder()).decodeCertificate(encoded)

        if (res is CertificateDecodingResult.Error)
            throw Exception("Failed to read certificate!", res.error.error)

        decoded = (res as CertificateDecodingResult.Success).greenCertificate
    }

    /**
     * Get person full name
     */
    val fullName get() = "${decoded.person.standardisedGivenName} ${decoded.person.standardisedFamilyName}"

    /**
     * Get certificate id
     */
    val id get() = decoded.getDgci()

    val dateOfBirth get() = decoded.dateOfBirth

    val recovery: RecoveryStatement? get() = decoded.recoveryStatements?.getOrNull(0)

    fun descText(ctx: Context): String {
        if (recovery != null)
            return ctx.resources.getString(
                R.string.desc_recovery_certificate,
                recovery!!.dateOfFirstPositiveTest
            )


        return ctx.resources.getString(R.string.desc_unknown_certificate)
    }
}